find_latest_installed_rust_toolchain

Function find_latest_installed_rust_toolchain 

pub fn find_latest_installed_rust_toolchain(
    requested_rust_toolchain: &RequestedRustToolchain,
) -> Result<RustToolchainName>
Find the latest installed Rust toolchain matching the request.

This does not update or install any Rust toolchain.

An exact request returns its name after checking that the toolchain is installed.

Errors

Returns an error if Rustup cannot list the installed toolchains or if no matching toolchain is installed.